#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['clean_enoa']

package_data = \
{'': ['*']}

setup(name='clean_enoa',
      version='0.1.0',
      description='This package makes requests to INEGI about unemployment in Mexico',
      author='Nepo Rojas • GECI',
      author_email='nepo.rojas@islas.org.mx',
      url='https://github.com/nepito/clean-enoa',
      packages=packages,
      package_data=package_data,
      python_requires='>=3',
     )
